==> enterprisemodules-wls_config-3.12.2.tar.gz: enterprisemodules-wls_config-3.12.2/lib/puppet/type/wls_opatch.rb <==
# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
$LOAD_PATH.unshift File.join(File.dirname(__FILE__), '../..')
require 'puppet_x/enterprisemodules/weblogic/core'

module Puppet
  Type.newtype(:wls_opatch) do
    def self.module_name
      'wls_config'
    end
    include EasyType
    include Puppet_X::EnterpriseModules::WebLogic::Access
    extend Puppet_X::EnterpriseModules::WebLogic::TitleParser

    desc <<-DESC
    This resource allows you to manage opatch patches on a specific middleware home.

          wls_opatch {'/opt/oracle/middleware12c:16175470':
            ensure                  => "present",
            jdk_home_dir            => "/usr/java/jdk1.7.0_45",
            os_user                 => "oracle",
            source                  => "/vagrant/p16175470_121200_Generic.zip",
          }

    DESC

    ensurable

    on_create do
      parameters[:source].process
      FileUtils.chmod_R(0o777, source) # So oracle and grid users can access them
      extracted_source = check_source_dir(source)
      provider.remove_incompatible_patches
      [:opatch, "apply #{extracted_source} -silent ", {}]
    end

    after_create do
      parameters[:source].clean
    end

    on_modify do
      fail 'Internal error. A patch is either there ot not. It cannot be modified.'
    end

    on_destroy do
      parameters[:source].process if parameters[:source]
      FileUtils.chmod_R(0o777, source) # So oracle and grid users can access them
      check_source_dir(source)
      [:opatch, "rollback -id #{patch_id} -silent ", {}]
    end

    after_destroy do
      parameters[:source].clean
    end

    map_titles_to_attributes([
                               /^((.+):(.+))$/, [:name, :oracle_product_home_dir, :patch_id]
                             ])

    parameter :name
    parameter :patch_id
    parameter :os_user
    parameter :oracle_product_home_dir
    parameter :jdk_home_dir
    parameter :source
    parameter :orainst_dir
    parameter :tmp_dir
    parameter :remove_patches_before
    parameter :force_remove

    def opatch(command, options = {})
      provider.opatch(command, options)
    end


    def check_source_dir(parent)
      patch_source_dir = Dir.glob("#{parent}/**/#{patch_id}").first
      raise "#{source} doesn't contain folder #{patch_id}" unless patch_source_dir

      patch_source_dir
    end
  end
end

==> enterprisemodules-wls_config-3.13.2.tar.gz: enterprisemodules-wls_config-3.13.2/lib/puppet/type/wls_opatch.rb <==
# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
$LOAD_PATH.unshift File.join(File.dirname(__FILE__), '../..')
require 'puppet_x/enterprisemodules/weblogic/core'

module Puppet
  Type.newtype(:wls_opatch) do
    def self.module_name
      'wls_config'
    end
    include EasyType
    include Puppet_X::EnterpriseModules::WebLogic::Access
    extend Puppet_X::EnterpriseModules::WebLogic::TitleParser

    desc <<-DESC
    This resource allows you to manage opatch patches on a specific middleware home.

          wls_opatch {'/opt/oracle/middleware12c:16175470':
            ensure                  => "present",
            jdk_home_dir            => "/usr/java/jdk1.7.0_45",
            os_user                 => "oracle",
            source                  => "/vagrant/p16175470_121200_Generic.zip",
          }

    DESC

    ensurable

    on_create do
      parameters[:source].process
      FileUtils.chmod_R(0o777, source) # So oracle and grid users can access them
      extracted_source = check_source_dir(source)
      provider.remove_incompatible_patches
      [:opatch, "apply #{extracted_source} -silent ", {}]
    end

    after_create do
      parameters[:source].clean
    end

    on_modify do
      fail 'Internal error. A patch is either there ot not. It cannot be modified.'
    end

    on_destroy do
      parameters[:source]&.process
      FileUtils.chmod_R(0o777, source) # So oracle and grid users can access them
      check_source_dir(source)
      [:opatch, "rollback -id #{patch_id} -silent ", {}]
    end

    after_destroy do
      parameters[:source].clean
    end

    map_titles_to_attributes([
                               /^((.+):(.+))$/, [:name, :oracle_product_home_dir, :patch_id]
                             ])

    parameter :name
    parameter :patch_id
    parameter :os_user
    parameter :oracle_product_home_dir
    parameter :jdk_home_dir
    parameter :source
    parameter :orainst_dir
    parameter :tmp_dir
    parameter :remove_patches_before
    parameter :force_remove

    def opatch(command, options = {})
      provider.opatch(command, options)
    end

    def check_source_dir(parent)
      patch_source_dir = Dir.glob("#{parent}/**/#{patch_id}").first
      raise "#{source} doesn't contain folder #{patch_id}" unless patch_source_dir

      patch_source_dir
    end
  end
end
